SingleFaceState class

Inheritance

Constructors

SingleFaceState({required double? x, required double? y, required double? z, required Rect boundingBox})
SingleFaceState.fromFace(Face face)
factory

Properties

boundingBox Rect
final
count int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isFaceStaight bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double?
final
y double?
final
z double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited