FaceCameraController class
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
CameraValue> - CameraController
- FaceCameraController
Constructors
- FaceCameraController({required CameraDescription description, Duration processDelay = const Duration(milliseconds: 100), ResolutionPreset resolutionPreset = ResolutionPreset.high, FaceDetectorOptions? faceDetectorOptions, bool enableAudio = false, ImageFormatGroup? imageFormatGroup})
Properties
- cameraId → int
-
The camera identifier with which the controller is associated.
no setterinherited
- description → CameraDescription
-
The properties of the camera device controlled by this controller.
no setterinherited
- enableAudio → bool
-
Whether to include audio when recording a video.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- imageFormatGroup → ImageFormatGroup?
-
The ImageFormatGroup describes the output of the raw image format.
finalinherited
- mediaSettings → MediaSettings
-
The media settings this controller is targeting.
finalinherited
- processDelay → Duration
-
final
- resolutionPreset → ResolutionPreset
-
The resolution this controller is targeting.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
FaceState> -
no setter
- value ↔ CameraValue
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
buildPreview(
) → Widget -
Returns a widget showing a live camera preview.
inherited
-
debugCheckIsDisposed(
) → void -
Checks whether CameraController.dispose has completed successfully.
inherited
-
dispose(
) → Future< void> -
Releases the resources of this camera.
override
-
getExposureOffsetStepSize(
) → Future< double> -
Gets the supported step size for exposure offset for the selected camera in EV units.
inherited
-
getMaxExposureOffset(
) → Future< double> -
Gets the maximum supported exposure offset for the selected camera in EV units.
inherited
-
getMaxZoomLevel(
) → Future< double> -
Gets the maximum supported zoom level for the selected camera.
inherited
-
getMinExposureOffset(
) → Future< double> -
Gets the minimum supported exposure offset for the selected camera in EV units.
inherited
-
getMinZoomLevel(
) → Future< double> -
Gets the minimum supported zoom level for the selected camera.
inherited
-
initialize(
{bool initializeProccessImage = true}) → Future< void> -
Initializes the camera on the device.
override
-
lockCaptureOrientation(
[DeviceOrientation? orientation]) → Future< void> -
Locks the capture orientation.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
pausePreview(
) → Future< void> -
Pauses the current camera preview
inherited
-
pauseVideoRecording(
) → Future< void> -
Pause video recording.
inherited
-
prepareForVideoRecording(
) → Future< void> -
Prepare the capture session for video recording.
inherited
-
processImage(
InputImage inputImage) → Future< List< Face> > -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resumePreview(
) → Future< void> -
Resumes the current camera preview
inherited
-
resumeVideoRecording(
) → Future< void> -
Resume video recording after pausing.
inherited
-
setDescription(
CameraDescription description) → Future< void> -
Sets the description of the camera.
inherited
-
setExposureMode(
ExposureMode mode) → Future< void> -
Sets the exposure mode for taking pictures.
inherited
-
setExposureOffset(
double offset) → Future< double> -
Sets the exposure offset for the selected camera.
inherited
-
setExposurePoint(
Offset? point) → Future< void> -
Sets the exposure point for automatically determining the exposure value.
inherited
-
setFlashMode(
FlashMode mode) → Future< void> -
Sets the flash mode for taking pictures.
inherited
-
setFocusMode(
FocusMode mode) → Future< void> -
Sets the focus mode for taking pictures.
inherited
-
setFocusPoint(
Offset? point) → Future< void> -
Sets the focus point for automatically determining the focus value.
inherited
-
setZoomLevel(
double zoom) → Future< void> -
Set the zoom level for the selected camera.
inherited
-
startImageStream(
onLatestImageAvailable onAvailable) → Future< void> -
Start streaming images from platform camera.
inherited
-
startVideoRecording(
{onLatestImageAvailable? onAvailable, bool imageStream = false}) → Future< void> -
Start a video recording.
override
-
stopImageStream(
) → Future< void> -
Stop streaming images from platform camera.
inherited
-
stopVideoRecording(
{bool imageStream = false}) → Future< XFile> -
Stops the video recording and returns the file where it was saved.
override
-
supportsImageStreaming(
) → bool -
Check whether the camera platform supports image streaming.
inherited
-
takePicture(
) → Future< XFile> -
Captures an image and returns the file where it was saved.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unlockCaptureOrientation(
) → Future< void> -
Unlocks the capture orientation.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited